@@ -30,15 +30,9 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 	:param return_data: if True, the whole data frome with the new column is returned, otherwise just the column
 	:rtype: SparkDF
 	"""
-	data = data.select(
-		*[
-			f.col(col).cast(StringType()).alias(col)
-			for col in data.columns
-		]
-	)
 	data = data.withColumn(
 		name, f.concat_ws(
-			sep, *[f.col(col) for col in data.columns]
+			sep, *[f.col(col).cast(StringType()) for col in data.columns]
 		)
 	)
 
